@@ -10,11 +10,12 @@ use File::Spec; #not really needed because File::Copy already gets it, but for g
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(fcopy rcopy dircopy);
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 sub VERSION { $VERSION; }
 
 our $MaxDepth = 0;
 our $KeepMode = 1;
+our $CPRFComp = 0; 
 our $CopyLink = eval { symlink '',''; 1 } || 0;
 
 sub fcopy { 
@@ -30,10 +31,25 @@ sub fcopy {
 sub rcopy { -d $_[0] ? dircopy(@_) : fcopy(@_) }
 
 sub dircopy {
-   croak "$_[0] and $_[1] are the same" if $_[0] eq $_[1];
+   croak "$_[0] and $_[1] are the same" if $_[0] eq $_[1]; # todo: check if absolutley the same and  not just different strings
+                                                           # absoulte and relative, /dir1/file /dir2/file where dir is a link to dir2, etc
    croak "$_[0] is not a directory" if !-d $_[0];
    croak "$_[1] is not a directory" if -e $_[1] && !-d $_[1];
-   mkdir $_[1] or return if !-d $_[1];
+
+   if(!-d $_[1]) {
+      my @parts = File::Spec->splitdir($_[1]);
+      my $pth = $parts[0];
+      for(0..$#parts) {
+         mkdir $pth or return if !-d $pth;
+         $pth = File::Spec->catfile($pth, $parts[$_ + 1]) unless ($_ + 1) == $#parts;
+      }
+   } else {
+      if($CPRFComp) {
+         my @parts = File::Spec->splitdir($_[0]);
+         while($parts[ $#parts ] eq '') { pop @parts; }
+         $_[1] = File::Spec->catfile($_[1], $parts[$#parts]);
+      }
+   }
    my $baseend = $_[1];
    my $level = 0;
    my $filen = 0;
@@ -59,13 +75,13 @@ sub dircopy {
       for(@files) {
          my $org = File::Spec->catfile($str,$_);
          my $new = File::Spec->catfile($end,$_);
-         if(-d $org) {
+         if(-l $org && $CopyLink) {
+            symlink readlink($org), $new or return;
+         } elsif(-d $org) {
             $recurs->($org,$new,$buf) if defined $buf;
             $recurs->($org,$new) if !defined $buf;
             $filen++;
             $dirn++;
-         } elsif(-l $org && $CopyLink) {
-            symlink readlink($org), $new or return;
          } else {
             copy($org,$new,$buf) or return if defined $buf;
             copy($org,$new) or return if !defined $buf;
@@ -113,7 +129,7 @@ returns the same as File::Copy::copy() in scalar context and 1,0,0 in list conte
 =head2 dircopy()
 
 This function recursively traverses the $orig directory's structure and recursively copies it to the $new directory.
-$new is created if necessary.
+$new is created if necessary (multiple non existant directories is ok (IE foo/bar/baz). The script logically and portably creates all of them if necessary).
 It attempts to preserve the mode (see Preserving Mode below) and 
 by default it copies all the way down into the directory, (see Managing Depth) below.
 If a directory is not specified it croaks just like fcopy croaks if its not a file that is specified.
@@ -150,13 +166,36 @@ Perl's symlink() is used instead of File::Copy's copy()
 You can customize this behavior by setting $File::Copy::Recursive::CopyLink to a true or false value.
 It is already set to true or false dending on your system's support of symlinks so you can check it with an if statement to see how it will behave:
 
-
     if($File::Copy::Recursive::CopyLink) {
         print "Symlinks will be preserved\n";
     } else {
         print "Symlinks will not be preserved because your system does not support it\n";
     }
 
+=head2 Emulating cp -rf dir1/ dir2/
+
+By default dircopy($dir1,$dir2) will put $dir1's contents right into $dir2 whether $dir2 exists or not.
+
+You can make dircopy() emulate cp -rf by setting $File::Copy::Recursive::CPRFComp to true.
+
+That means that if $dir2 exists it puts the contents into $dir2/$dir1 instead of $dir1 just like cp -rf.
+if $dir2 does not exist then the contents go into $dir2 like normal (also like cp -rf)
+
+So assuming 'foo/file':
+
+    dircopy('foo', 'bar') or die $!;
+    # if bar does not exist the result is bar/file
+    # if bar does exist the result is bar/file
+
+    $File::Copy::Recursive::CPRFComp = 1;
+    dircopy('foo', 'bar') or die $!;
+    # if bar does not exist the result is bar/file
+    # if bar does exist the result is bar/foo/file
+
+=head2 TO DO
+
+Add to dircopy()'s check as mentioned in source.
+
 =head1 SEE ALSO
 
  L<File::Copy> L<File::Spec>
